@@ -222,7 +222,7 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
     }
 
     @Override
-    public void handleHam(final int accountId, final String spamFullname, final String[] mailIDs, final boolean move, final Session session) throws OXException {
+    public void handleHam(final int accountId, final String spamFullName, final String[] mailIDs, final boolean move, final Session session) throws OXException {
         final MailService mailService = Services.getService(MailService.class);
         if (null == mailService) {
             throw SpamhandlerSpamassassinExceptionCode.MAILSERVICE_MISSING.create();
@@ -233,7 +233,7 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
             mailAccess.connect();
             final PropertyHandler instance2 = PropertyHandler.getInstance();
             final SpamdSettings spamdSettings = getSpamdSettings(session, instance2);
-            unwrap(new UnwrapParameter(spamFullname, move, mailAccess), mailIDs, spamdSettings, accountId, session);
+            unwrap(new UnwrapParameter(spamFullName, move, mailAccess), mailIDs, spamdSettings, accountId, session);
         } finally {
             if (null != mailAccess) {
                 mailAccess.close();
@@ -242,7 +242,7 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
     }
 
     @Override
-    public void handleSpam(final int accountId, final String fullname, final String[] mailIDs, final boolean move, final Session session) throws OXException {
+    public void handleSpam(final int accountId, final String fullName, final String[] mailIDs, final boolean move, final Session session) throws OXException {
         /*
          * Copy to confirmed spam folder
          */
@@ -250,19 +250,19 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
         if (null == mailService) {
             throw SpamhandlerSpamassassinExceptionCode.MAILSERVICE_MISSING.create();
         }
-        LOGGER.debug("Handle spam for messages {} from folder {} in account {} (user={}, context={})", Arrays.toString(mailIDs), fullname, accountId, session.getUserId(), session.getContextId());
+        LOGGER.debug("Handle spam for messages {} from folder {} in account {} (user={}, context={})", Arrays.toString(mailIDs), fullName, accountId, session.getUserId(), session.getContextId());
         MailAccess<?, ?> mailAccess = null;
         try {
             mailAccess = mailService.getMailAccess(session, accountId);
             mailAccess.connect();
             if (isCreateConfirmedSpam()) {
                 final String confirmedSpamFullname = mailAccess.getFolderStorage().getConfirmedSpamFolder();
-                mailAccess.getMessageStorage().copyMessages(fullname, confirmedSpamFullname, mailIDs, true);
-                LOGGER.debug("Spam messages {} from folder {} in account {} moved to confirmed-spam folder {} (user={}, context={})", Arrays.toString(mailIDs), fullname, accountId, confirmedSpamFullname, session.getUserId(), session.getContextId());
+                mailAccess.getMessageStorage().copyMessages(fullName, confirmedSpamFullname, mailIDs, true);
+                LOGGER.debug("Spam messages {} from folder {} in account {} copied to confirmed-spam folder {} (user={}, context={})", Arrays.toString(mailIDs), fullName, accountId, confirmedSpamFullname, session.getUserId(), session.getContextId());
             }
             final SpamdSettings spamdSettings = getSpamdSettings(session, PropertyHandler.getInstance());
             if (null != spamdSettings) {
-                final MailMessage[] mails = mailAccess.getMessageStorage().getMessages(fullname, mailIDs, new MailField[]{MailField.ID, MailField.FOLDER_ID});
+                final MailMessage[] mails = mailAccess.getMessageStorage().getMessages(fullName, mailIDs, new MailField[]{MailField.ID, MailField.FOLDER_ID});
                 spamdMessageProcessing(mails, spamdSettings, true, accountId, mailAccess, session);
             }
             if (move) {
@@ -270,8 +270,8 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
                  * Move to spam folder
                  */
                 final String spamFullname = mailAccess.getFolderStorage().getSpamFolder();
-                mailAccess.getMessageStorage().moveMessages(fullname, spamFullname, mailIDs, true);
-                LOGGER.debug("Spam messages {} from folder {} in account {} moved to spam folder {} (user={}, context={})", Arrays.toString(mailIDs), fullname, accountId, spamFullname, session.getUserId(), session.getContextId());
+                mailAccess.getMessageStorage().moveMessages(fullName, spamFullname, mailIDs, true);
+                LOGGER.debug("Spam messages {} from folder {} in account {} moved to spam folder {} (user={}, context={})", Arrays.toString(mailIDs), fullName, accountId, spamFullname, session.getUserId(), session.getContextId());
             }
         } finally {
             if (null != mailAccess) {
@@ -296,11 +296,23 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
     }
 
     private MailMessage[] getNestedMailsAndHandleOthersAsPlain(final UnwrapParameter paramObject, final String confirmedHamFullname, final String[] nestedMessages, final SpamdSettings spamdSettings, final int accountId, final Session session) throws OXException {
+        MailAccess<?, ?> mailAccess = paramObject.getMailAccess();
+        String spamFullname = paramObject.getSpamFullname();
+
         int nestedmessagelength = nestedMessages.length;
         List<MailMessage> nestedMails = new ArrayList<MailMessage>(nestedmessagelength);
         String[] exc = new String[1];
         for (int i = 0; i < nestedmessagelength; i++) {
-            MailPart wrapped = paramObject.getMailAccess().getMessageStorage().getAttachment(paramObject.getSpamFullname(), nestedMessages[i], "2");
+            MailPart wrapped;
+            try {
+                wrapped = mailAccess.getMessageStorage().getAttachment(spamFullname, nestedMessages[i], "2");
+            } catch (OXException e) {
+                if (false == MailExceptionCode.ATTACHMENT_NOT_FOUND.equals(e)) {
+                    throw e;
+                }
+                // The original message seems not to be nested
+                wrapped = mailAccess.getMessageStorage().getMessage(spamFullname, nestedMessages[i], false);
+            }
             wrapped.loadContent();
 
             MailMessage tmp = null;
@@ -341,6 +353,7 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
                 nestedMails.add(tmp);
             }
         }
+
         return nestedMails.toArray(new MailMessage[nestedMails.size()]);
     }
 
